==> torchcommon-0.7.5-py3-none-any.whl: torchcommon/config.py <==
#!/usr/bin/env python3

import io

__all__ = [
    'BaseConfig'
]


class BaseConfig(object):

    def __init__(self, args=None):
        if args is not None:
            self.load(args)

    def load(self, args):
        for name, value in self._get_attributes().items():
            if name.startswith('_'):
                continue
            if hasattr(args, name):
                setattr(self, name, getattr(args, name))

    def __str__(self):
        pairs = []
        max_len = 0
        for name, value in self._get_attributes().items():
            if name.startswith('_'):
                continue

            if value is None:
                value = 'None'
            elif isinstance(value, str):
                value = f'\'{value}\''
            else:
                value = str(value)

            break_line = value.find('\n')
            if break_line >= 0:
                value = value[:break_line]

            pairs.append((name, value))

            name_len = len(name)
            if name_len > max_len:
                max_len = name_len

        buffer = io.StringIO()
        for name, value in pairs:
            buffer.write(name.rjust(max_len))
            buffer.write(': ')
            buffer.write(value)
            buffer.write('\n')
        return buffer.getvalue()

    def _get_attributes(self):
        d = {}
        for name, value in self.__class__.__dict__.items():
            d[name] = value
        for name, value in self.__dict__.items():
            d[name] = value
        return d

==> torchcommon-0.7.6-py3-none-any.whl: torchcommon/config.py <==
#!/usr/bin/env python3

import io

__all__ = [
    'BaseConfig'
]


class BaseConfig(object):

    def __init__(self, args=None):
        if args is not None:
            self.load(args)

    def load(self, args):
        for name, value in self._get_attributes().items():
            if name.startswith('_'):
                continue
            if hasattr(args, name):
                setattr(self, name, getattr(args, name))

    def __str__(self):
        pairs = []
        max_len = 0
        for name, value in self._get_attributes().items():
            if name.startswith('_'):
                continue

            if value is None:
                value = 'None'
            elif isinstance(value, str):
                value = f'\'{value}\''
            else:
                value = str(value)

            break_line = value.find('\n')
            if break_line >= 0:
                value = value[:break_line]

            pairs.append((name, value))

            name_len = len(name)
            if name_len > max_len:
                max_len = name_len

        buffer = io.StringIO()
        for name, value in pairs:
            buffer.write(name.rjust(max_len))
            buffer.write(': ')
            buffer.write(value)
            buffer.write('\n')
        return buffer.getvalue()

    def _get_attributes(self):
        d = {}
        class_list = []
        base = self.__class__
        while base is not BaseConfig:
            class_list.append(base)
            base = base.__base__
        for clazz in reversed(class_list):
            for name, value in clazz.__dict__.items():
                d[name] = value
        for name, value in self.__dict__.items():
            d[name] = value
        return d
